# -*- coding: utf-8
from __future__ import unicode_literals, absolute_import

from django.forms import ModelForm, URLField, HiddenInput, Select
from djmoney.forms.fields import MoneyField
from djmoney.forms.widgets import MoneyWidget

from donations.models import Donation


class DonationForm(ModelForm):
    finished_uri = URLField(widget=HiddenInput())

    class Meta:  # pylint: disable=C1001
        model = Donation
        fields = ('amount', 'provider', 'frequency', 'finished_uri')

    def __init__(self, *args, **kwargs):
        super(DonationForm, self).__init__(*args, **kwargs)
        if hasattr(self, 'amounts'):
            self.amounts = [(i, i) if type(i) in [int, float] else i for i in self.amounts]
            donate_widget = MoneyWidget(amount_widget=Select(choices=self.amounts))
            self.fields['amount'] = MoneyField(currency_widget=donate_widget)



# -*- coding: utf-8
from __future__ import unicode_literals, absolute_import

from django.conf.urls import include, url

from donations.views import DonateAPI, VerifyAPI

api_urls = [
    url(r'^donate/$', DonateAPI.as_view(), name="donate"),
    url(r'^verify/(?P<pk>[0-9]+)$', VerifyAPI.as_view(), name="verify"),
]

donations = [
    url(r'^api/', include(api_urls, namespace="api")),
]

urlpatterns = [
    url(r'^', include(donations, namespace="donations"))
]



# -*- coding: utf-8
from __future__ import unicode_literals, absolute_import

import logging

from donations import app_settings

logger = logging.getLogger(__name__)


def load_frequencies():
    """Make sure the frequencies defined in settings are loaded in database"""
    frequencies = app_settings.DONATION_FREQUENCIES
    logger.debug('Loading Donation Frequencies')
    from donations.models import Frequency
    for name, period in frequencies.items():
        try:
            dp, created = Frequency.objects.get_or_create(name=name, interval=period)
            if created:
                logger.info('Loaded %s with interval of %s', name, period)
            else:
                logger.info('Frequency %s with interval of %s already exists', name, period)
        except Exception as exc:
            logger.warning("Could not load the Frequency model instance due to %s", exc)


def load_providers():
    """Make sure the providers defined in settings are loaded in database"""
    providers = app_settings.DONATION_PROVIDERS
    logger.debug('Loading Donation Providers')
    from donations.models import DonationProvider
    for name, klass in providers.items():
        try:
            dp, created = DonationProvider.objects.get_or_create(name=name, klass=klass)
            if created:
                logger.info('Loaded %s called %s', klass, name)
            else:
                logger.info('Provider %s called %s already exists', klass, name)
        except Exception as exc:
            logger.warning("Could not load the DonationProvider model instance due to %s", exc)



# -*- coding: utf-8
from django.apps import AppConfig


class DonationsConfig(AppConfig):
    name = 'donations'
    verbose_name = "Django Donations"

    def ready(self):
        from .config_loaders import load_providers, load_frequencies
        load_providers()
        load_frequencies()



#!/usr/bin/env python
# -*- coding: utf-8 -*-
import codecs

try:
    from setuptools import setup
except ImportError:
    from distutils.core import setup

version = '0.5.0'

readme = codecs.open('README.rst', 'r', 'utf-8').read()
history = codecs.open('HISTORY.rst', 'r', 'utf-8').read().replace('.. :changelog:', '')

install_requires = [
    'django-timedeltafield',
    'django-money',
    'djangorestframework',
    'requests',
    'py-moneyed',
    'six',
]

setup(
    name='django-donations',
    version=version,
    description="""Reusable django app to receive & track donations on charitable sites""",
    long_description=readme + '\n\n' + history,
    author='Andrew Miller',
    author_email='dev@founders4schools.org.uk',
    url='https://github.com/founders4schools/django-donations',
    packages=[
        'donations',
    ],
    include_package_data=True,
    install_requires=install_requires,
    license="BSD",
    zip_safe=False,
    keywords='django-donations',
    classifiers=[
        'Development Status :: 3 - Alpha',
        'Framework :: Django',
        'Framework :: Django :: 1.8',
        'Framework :: Django :: 1.9',
        'Framework :: Django :: 1.10',
        'Intended Audience :: Developers',
        'License :: OSI Approved :: BSD License',
        'Natural Language :: English',
        'Programming Language :: Python :: 2',
        'Programming Language :: Python :: 2.7',
        'Programming Language :: Python :: 3',
        'Programming Language :: Python :: 3.3',
        'Programming Language :: Python :: 3.4',
        'Programming Language :: Python :: 3.5',
    ],
)



# -*- coding: utf-8
from __future__ import unicode_literals, absolute_import

from datetime import timedelta

from django.conf import settings

JUST_GIVING_WEB_URL = getattr(settings, 'JUST_GIVING_WEB_URL', 'http://v3-sandbox.justgiving.com')
JUST_GIVING_API_URL = getattr(settings, 'JUST_GIVING_API_URL', 'http://api-sandbox.justgiving.com')
JUST_GIVING_CHARITY_ID = getattr(settings, 'JUST_GIVING_CHARITY_ID', '2050')  # demo id
JUST_GIVING_APP_ID = getattr(settings, 'JUST_GIVING_APP_ID', 'XXXXX')

CURRENCIES = getattr(settings, 'CURRENCIES', ['GBP', 'EUR', 'AUD', 'USD', 'ZAR', 'CAD', 'AED', 'HKD', 'SGD'])

DONATION_FREQUENCIES = getattr(settings, 'DONATION_FREQUENCIES', {
    'single': timedelta(days=0),
})
DONATION_PROVIDERS = getattr(settings, 'DONATION_PROVIDERS', {
    'Just Giving': 'just_giving.SimpleDonationProvider'
})
